﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Controls.Charts;

using System.ComponentModel;


namespace AxisDataTemplateAndFormat
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        DataView ListDataView = new DataView();

        public MainWindow()
        {
            InitializeComponent();

            DataContext = ListDataView;
        }

        private void btnChange_Click(object sender, RoutedEventArgs e)
        {
            if ( ListDataView.DisplayUnits == 1 )
            {
                ListDataView.DisplayUnits = 1000000000;
                ListDataView.NumDecimals = 2;
            }
            else
            {
                ListDataView.DisplayUnits = 1;
                ListDataView.NumDecimals = 0;
            }
        }

    }

    public class Data
    {
        public DataView Parent { get; set; }
        public double Label { get; set; }
        public int Value { get; set; }
    }


    public class DataView : INotifyPropertyChanged
    {
        private int _displayUnits = 1;
        public int DisplayUnits
        {
            get { return _displayUnits; }
            set
            {
                if (_displayUnits != value)
                {
                    _displayUnits = value;
                    OnPropertyChanged("DisplayUnits");
                }
            }
        }

        private int _numDecimals = 0;
        public int NumDecimals
        {
            get { return _numDecimals; }
            set
            {
                if (_numDecimals != value)
                {
                    _numDecimals = value;
                    OnPropertyChanged("NumDecimals");
                }
            }
        }


        private List<Data> _data = new List<Data>();
        public List<Data> DataList
        {
            get { return _data; }
            set
            {
                if (_data != value)
                {
                    _data = value;
                    OnPropertyChanged("DataList");
                }
            }
        }


        public DataView()
        {
            Random r = new Random();
            for (int i = 0; i < 10; i++)
            {
                DataList.Add(new Data { Parent = this, Label = r.NextDouble(), Value = r.Next(1500000000) });
            }
        }

        protected delegate void PropertyChangedDelegate(object sender, string propertyName);
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null)
                handler(sender, e);
        }
        protected void OnPropertyChanged(String propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }




    public class LabelFormatConerter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            AxisItemDataContext context = value as AxisItemDataContext;
            if (context.Item is Data)
            {
                Data item = context.Item as Data;

                return "(" + item.Label.ToString("N2") + ")";
            }
            else
            {
                double val = (double)context.Item;

                return (val / 1000000000).ToString("N2") + " b";
            }
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }


    public class LabelFormatConverterMulti : IMultiValueConverter
    {
        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            
            AxisItemDataContext context = values[0] as AxisItemDataContext;
            if (context.Item is Data)
            {
                Data item = context.Item as Data;

                return "(" + item.Label.ToString("e2") + ")";
            }
            else
            {
                if (values[0] == DependencyProperty.UnsetValue
                    || values[1] == DependencyProperty.UnsetValue
                    || values[2] == DependencyProperty.UnsetValue)
                    return "";

                double value = (double)context.Item;
                int units = (int)values[1];
                int prec = (int)values[2];

                //if (type.Equals("Millions"))
                //{
                return (value / units).ToString("N" + prec);
                //}
                //else
                //{
                //    return (value / 1000000000).ToString("N" + prec) + " b";
                //}
            }
            
            
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}
